@@ -39,7 +39,10 @@ import org.slf4j.LoggerFactory;
 import picocli.CommandLine.Command;
 import picocli.CommandLine.Option;
 
-@Command(name = "serve", description = "Start an IP to location web service.")
+@Command(
+    name = "serve",
+    description = "Start an IP to location web service.")
+@SuppressWarnings("squid:S106")
 public class Serve implements Callable<Integer> {
 
   private static final Logger logger = LoggerFactory.getLogger(Serve.class);
