@@ -22,15 +22,18 @@ import java.net.URI;
 import java.nio.file.Path;
 import java.util.concurrent.Callable;
 import org.apache.baremaps.cli.Options;
+import org.apache.baremaps.tasks.ExportVectorTiles;
 import org.apache.baremaps.workflow.WorkflowContext;
-import org.apache.baremaps.workflow.tasks.ExportVectorTiles;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import picocli.CommandLine.Command;
 import picocli.CommandLine.Mixin;
 import picocli.CommandLine.Option;
 
-@Command(name = "export", description = "Export vector tiles from the database.")
+@Command(
+    name = "export",
+    description = "Export vector tiles from the database.")
+@SuppressWarnings("squid:S106")
 public class Export implements Callable<Integer> {
 
   private static final Logger logger = LoggerFactory.getLogger(Export.class);
@@ -55,7 +58,7 @@ public class Export implements Callable<Integer> {
 
   @Option(names = {"--format"}, paramLabel = "FORMAT",
       description = "The format of the repository.")
-  private ExportVectorTiles.Format format = ExportVectorTiles.Format.file;
+  private ExportVectorTiles.Format format = ExportVectorTiles.Format.FILE;
 
   @Override
   public Integer call() throws Exception {
