@@ -25,16 +25,19 @@ import java.util.Arrays;
 import java.util.Map;
 import java.util.concurrent.Callable;
 import org.apache.baremaps.cli.Options;
-import org.apache.baremaps.vectortile.style.Style;
-import org.apache.baremaps.vectortile.style.StyleSource;
-import org.apache.baremaps.vectortile.tileset.Tileset;
+import org.apache.baremaps.maplibre.style.Style;
+import org.apache.baremaps.maplibre.style.StyleSource;
+import org.apache.baremaps.maplibre.tileset.Tileset;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import picocli.CommandLine.Command;
 import picocli.CommandLine.Mixin;
 import picocli.CommandLine.Option;
 
-@Command(name = "init", description = "Init configuration files.")
+@Command(
+    name = "init",
+    description = "Init configuration files.")
+@SuppressWarnings("squid:S106")
 public class Init implements Callable<Integer> {
 
   private static final Logger logger = LoggerFactory.getLogger(Init.class);
