@@ -134,11 +134,12 @@ public final class TileCoord implements Comparable<TileCoord> {
    * @return the tile
    */
   public static TileCoord fromLonLat(double lon, double lat, int z) {
-    int x = (int) ((lon + 180.0) / 360.0 * (1 << z));
-    int y = (int) ((1
-        - Math.log(Math.tan(Math.toRadians(lat)) + 1 / Math.cos(Math.toRadians(lat))) / Math.PI)
-        / 2.0 * (1 << z));
-    return new TileCoord(x, y, z);
+    return new TileCoord(
+        (int) ((lon + 180.0) / 360.0 * (1 << z)),
+        (int) ((1 - Math.log(
+            Math.tan(Math.toRadians(lat)) + 1 / Math.cos(Math.toRadians(lat))) / Math.PI) / 2.0
+            * (1 << z)),
+        z);
   }
 
   /**
@@ -190,6 +191,42 @@ public final class TileCoord implements Comparable<TileCoord> {
     return new TileCoord(x / 2, y / 2, z - 1);
   }
 
+  /**
+   * Returns the tile coordinate at the left of the current tile.
+   *
+   * @return the left tile
+   */
+  public TileCoord left() {
+    return new TileCoord(x - 1, y, z);
+  }
+
+  /**
+   * Returns the tile coordinate at the right of the current tile.
+   *
+   * @return the right tile
+   */
+  public TileCoord right() {
+    return new TileCoord(x + 1, y, z);
+  }
+
+  /**
+   * Returns the tile coordinate at the top of the current tile.
+   *
+   * @return the top tile
+   */
+  public TileCoord top() {
+    return new TileCoord(x, y - 1, z);
+  }
+
+  /**
+   * Returns the tile coordinate at the bottom of the current tile.
+   *
+   * @return the bottom tile
+   */
+  public TileCoord bottom() {
+    return new TileCoord(x, y + 1, z);
+  }
+
   /**
    * Returns the envelope of the tile coordinate.
    *
