@@ -20,8 +20,8 @@ package org.apache.baremaps.config;
 import static org.junit.jupiter.api.Assertions.assertEquals;
 
 import java.io.IOException;
+import org.apache.baremaps.maplibre.style.Style;
 import org.apache.baremaps.testing.TestFiles;
-import org.apache.baremaps.vectortile.style.Style;
 import org.junit.jupiter.api.Test;
 import org.testcontainers.shaded.com.fasterxml.jackson.databind.ObjectMapper;
 
