@@ -28,13 +28,15 @@ import java.util.ArrayList;
 import java.util.List;
 import java.util.Optional;
 import net.ripe.ipresource.IpResourceRange;
+import org.apache.baremaps.rpsl.RpslObject;
+import org.apache.baremaps.rpsl.RpslReader;
+import org.apache.baremaps.tasks.CreateGeonamesIndex;
 import org.apache.baremaps.testing.TestFiles;
 import org.apache.baremaps.utils.FileUtils;
 import org.apache.baremaps.workflow.WorkflowContext;
-import org.apache.baremaps.workflow.tasks.CreateGeonamesIndex;
 import org.apache.lucene.search.SearcherFactory;
 import org.apache.lucene.search.SearcherManager;
-import org.apache.lucene.store.MMapDirectory;
+import org.apache.lucene.store.FSDirectory;
 import org.junit.jupiter.api.AfterAll;
 import org.junit.jupiter.api.BeforeAll;
 import org.junit.jupiter.api.BeforeEach;
@@ -49,7 +51,7 @@ import org.sqlite.SQLiteDataSource;
  */
 class IpLocObjectTest {
 
-  private static List<NicObject> nicObjects;
+  private static List<RpslObject> rpslObjects;
   private static IpLocMapper ipLocMapper;
   private static List<IpLocObject> ipLocObjects;
   private static IpLocRepository iplocRepository;
@@ -59,21 +61,24 @@ class IpLocObjectTest {
   @BeforeAll
   public static void beforeAll() throws Exception {
     // Load the NIC sample objects
-    nicObjects = NicData.sample("ripe/sample.txt");
+    var file = TestFiles.resolve("baremaps-testing/data/ripe/sample.txt");
+    try (var input = Files.newInputStream(file)) {
+      rpslObjects = new RpslReader().read(input).toList();
+    }
 
     // Init the geocoder service
     directory = Files.createTempDirectory(Paths.get("."), "geocoder_");
 
     // Create the geonames index
-    var data = TestFiles.resolve("geonames/sample.txt");
+    var data = TestFiles.resolve("baremaps-testing/data/geonames/sample.txt");
     var task = new CreateGeonamesIndex(data, directory);
     task.execute(new WorkflowContext());
 
     // Create the IPLoc mapper
-    var dir = MMapDirectory.open(directory);
+    var dir = FSDirectory.open(directory);
     var searcherManager = new SearcherManager(dir, new SearcherFactory());
     ipLocMapper = new IpLocMapper(searcherManager);
-    ipLocObjects = nicObjects.stream()
+    ipLocObjects = rpslObjects.stream()
         .map(ipLocMapper)
         .filter(Optional::isPresent)
         .map(Optional::get)
