@@ -12,5 +12,8 @@
 -- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 -- See the License for the specific language governing permissions and
 -- limitations under the License.
-CREATE EXTENSION IF NOT EXISTS hstore;
-CREATE EXTENSION IF NOT EXISTS postgis;
+CREATE
+    EXTENSION IF NOT EXISTS hstore;
+
+CREATE
+    EXTENSION IF NOT EXISTS postgis;
