@@ -12,4 +12,7 @@
 -- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 -- See the License for the specific language governing permissions and
 -- limitations under the License.
-CREATE INDEX IF NOT EXISTS overture_admins_administrative_boundary_materialized_view_gist ON overture_admins_administrative_boundary_materialized_view USING GIST(geom);
\ No newline at end of file
+CREATE
+    INDEX IF NOT EXISTS overture_admins_administrative_boundary_materialized_view_gist ON
+    overture_admins_administrative_boundary_materialized_view
+        USING GIST(geom);
\ No newline at end of file
