@@ -12,20 +12,23 @@
 -- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 -- See the License for the specific language governing permissions and
 -- limitations under the License.
-CREATE MATERIALIZED VIEW IF NOT EXISTS overture_admins_administrative_boundary_materialized_view AS
-SELECT
-    -- Generate a unique id for each row
-    row_number() OVER () AS id,
-
-    -- Rename the geometry column
-    st_simplifypreservetopology(geometry, 78270 / power(2, 2)) AS geom,
-
-    -- Aggregate other fields into a jsonb tags field
-    jsonb_build_object(
-        'admin_level', admin_level,
-        'version', version,
-        'sources', sources,
-        'population', population,
-        'names', names
-    ) AS tags
-FROM overture_admins_administrative_boundary;
\ No newline at end of file
+CREATE
+    MATERIALIZED VIEW IF NOT EXISTS overture_admins_administrative_boundary_materialized_view AS SELECT -- Generate a unique id for each rowROW_NUMBER() OVER() AS id, -- Rename the geometry column
+        st_simplifypreservetopology(
+            geometry,
+            78270 / POWER( 2, 2 )
+        ) AS geom, -- Aggregate other fields into a jsonb tags field
+        jsonb_build_object(
+            'admin_level',
+            admin_level,
+            'version',
+            version,
+            'sources',
+            sources,
+            'population',
+            population,
+            'names',
+            names
+        ) AS tags
+    FROM
+        overture_admins_administrative_boundary;
\ No newline at end of file
